=========
Changelog
=========

Version 0.1.3
=============

- Increasing formats supported by HTTP X-Robots-Tag header.

Version 0.1.2
=============

- Resolved minor linting issues.

Version 0.1.1
=============

- Pinning some dependencies for a more predictable build.

Version 0.1.0
=============

- Initial commit. Welcome!
